==> apache-seatunnel-incubating-2.1.3-src.tar.gz: apache-seatunnel-incubating-2.1.3-src/seatunnel-transforms/seatunnel-transforms-spark/seatunnel-transform-spark-replace/src/test/scala/org/apache/seatunnel/spark/transform/TestReplace.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.spark.transform

import junit.framework.TestCase.assertEquals
import org.junit.Test

class TestReplace {
  @Test
  def testReplaceReg() {
    val udf = new Replace
    assertEquals(
      "world",
      udf.replace("hello world", "([^ ]*) ([^ ]*)", "$2", isRegex = true, replaceFirst = false))
    assertEquals(
      "hello world",
      udf.replace("hello world", "([^ ]*)", "$1", isRegex = true, replaceFirst = true))
  }

  @Test
  def testReplaceLiteral() {
    val udf = new Replace
    assertEquals("fee", udf.replace("foo", "o", "e", isRegex = false, replaceFirst = false))
    assertEquals("feo", udf.replace("foo", "o", "e", isRegex = false, replaceFirst = true))
  }
}

==> apache-seatunnel-incubating-2.3.0-src.tar.gz: apache-seatunnel-incubating-2.3.0-src/seatunnel-transforms/seatunnel-transforms-spark/seatunnel-transform-spark-replace/src/test/scala/org/apache/seatunnel/spark/transform/TestReplace.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.spark.transform

import org.junit.jupiter.api.Assertions.assertEquals
import org.junit.jupiter.api.Test

class TestReplace {
  @Test
  def testReplaceReg() {
    val udf = new Replace
    assertEquals(
      "world",
      udf.replace("hello world", "([^ ]*) ([^ ]*)", "$2", isRegex = true, replaceFirst = false))
    assertEquals(
      "hello world",
      udf.replace("hello world", "([^ ]*)", "$1", isRegex = true, replaceFirst = true))
  }

  @Test
  def testReplaceLiteral() {
    val udf = new Replace
    assertEquals("fee", udf.replace("foo", "o", "e", isRegex = false, replaceFirst = false))
    assertEquals("feo", udf.replace("foo", "o", "e", isRegex = false, replaceFirst = true))
  }
}
